# neutralocean
Calculate neutral surfaces in the ocean, using Python

# Installation
Simply execute either
```
$ pip install neutralocean
```
if you use pip, or
```
$ conda install -c conda-forge neutralocean
```
if you use conda.

# Usage
Try running the example script:
```
python /path/to/neutralocean/neutralocean/examples/run_OCCA.py
```
E.g. if you use miniconda, that might be in `~/miniconda3/envs/<YOUR-ENVIRONMENT-NAME>/lib/python<VERSION-NUMBER>/site-packages/neutralocean/`
If that runs, we're in business.  
Take a look at that example script, `run_OCCA.py`.
It is documented and will walk you through loading an ocean model dataset, selecting an equation of state, calculating various approximately neutral surfaces, and more. 

Uploading the sphinx-generated documentation to a website remains a work-in-progress.  Sorry.  Get in touch with me if you want to help, or need help.  In the meantime, read the documentation inside the code -- it's essentially the same.